Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2185)

Unified Diff: content/browser/service_worker/service_worker_database.cc

Issue 2716583003: Rename Origin.unique() to opaque().
Patch Set: Update new uses post-rebase Created 3 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/service_worker/service_worker_database.cc
diff --git a/content/browser/service_worker/service_worker_database.cc b/content/browser/service_worker/service_worker_database.cc
index e135cdf57968de05899d7ffae608d04d13b0aeb9..1c9fecc1738a76a3f998d18df8ab7c58f1eb2839 100644
--- a/content/browser/service_worker/service_worker_database.cc
+++ b/content/browser/service_worker/service_worker_database.cc
@@ -800,7 +800,7 @@ ServiceWorkerDatabase::Status ServiceWorkerDatabase::DeleteRegistration(
leveldb::WriteBatch batch;
// Remove |origin| from unique origins if a registration specified by
// |registration_id| is the only one for |origin|.
// TODO(nhiroki): Check the uniqueness by more efficient way.
std::vector<RegistrationData> registrations;
@@ -1153,7 +1153,7 @@ ServiceWorkerDatabase::Status ServiceWorkerDatabase::DeleteAllDataForOrigins(
if (!origin.is_valid())
return STATUS_ERROR_FAILED;
// Delete from the unique origin list.
batch.Delete(CreateUniqueOriginKey(origin));
// Delete from the foreign fetch origin list.
@@ -1370,7 +1370,7 @@ ServiceWorkerDatabase::Status ServiceWorkerDatabase::ParseRegistrationData(
}
for (int i = 0; i < data.foreign_fetch_origin_size(); ++i) {
url::Origin parsed_origin(GURL(data.foreign_fetch_origin(i)));
- if (parsed_origin.unique()) {
+ if (parsed_origin.opaque()) {
DLOG(ERROR) << "Foreign fetch origin '" << data.foreign_fetch_origin(i)
<< "' is not valid.";
return ServiceWorkerDatabase::STATUS_ERROR_CORRUPTED;
@@ -800,7 +800,7 @@ ServiceWorkerDatabase::Status ServiceWorkerDatabase::DeleteRegistration(
leveldb::WriteBatch batch;
- // Remove |origin| from unique origins if a registration specified by
+ // Remove |origin| from opaque origins if a registration specified by
// |registration_id| is the only one for |origin|.
// TODO(nhiroki): Check the uniqueness by more efficient way.
@@ -1153,7 +1153,7 @@ ServiceWorkerDatabase::Status ServiceWorkerDatabase::DeleteAllDataForOrigins(
if (!origin.is_valid())
return STATUS_ERROR_FAILED;
- // Delete from the unique origin list.
+ // Delete from the opaque origin list.
batch.Delete(CreateUniqueOriginKey(origin));
// Delete from the foreign fetch origin list.

Powered by Google App Engine
This is Rietveld 408576698